Exception: Leakferret::BinaryNotFoundError
- Defined in:
- lib/leakferret/error.rb
Overview
Raised when the native binary cannot be located or downloaded (no pinned
checksum for the platform, a failed download, or a bad LEAKFERRET_BIN).
Raised when the native binary cannot be located or downloaded (no pinned
checksum for the platform, a failed download, or a bad LEAKFERRET_BIN).